/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef CONFIGSTORE_H
#define CONFIGSTORE_H

#include <QHash>
#include <QObject>
#include <QDir>
#include <QFile>
#include <QTextStream>
#include <QStringList>
#include <QString>
#include <QHashIterator>
#include <iostream>
#include <libpws/util.h>

class ConfigStore
{
    public:
        /**
         * Preference types.
         */
        enum PREFS { ALL, PWS, APP };

        /**
         * Loads Preferences in file at path.
         */
        static void loadConfig (const QString & path);

        /**
         * Save the configuration into store["configfile"].
         */
        static void saveConfig ();

        /**
         * Set default values.
         *
         * @param type - Whether all perferences, only application specific
         *               preferences or only pws database specific preferences
         *               should be resetted.
         */
        static void defaults (ConfigStore::PREFS type = ALL);

        /**
         * Adds a recent file entry.
         */
        static void addRecentFile (const QString & file);

        /**
         * This is the main store object and contains all
         * settings.
         */
        static QHash<QString, QString> store;

    protected:
        /** 
         * These preferences will be stored inside the .pwsrc file.
         */
        static QString params[];

        /**
         * Returns true if param is a application specific preference which
         * should be saved inside the configuration file.
         */
        static bool validParam (const QString & param);
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
