/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include <QApplication>
#include "configstore/configstore.h"
#include "libpws/init.h"
#include "mainwindow.h"

int main(int argc, char *argv[])
{
    Q_INIT_RESOURCE(pws);

    if (getenv("HOMESHARE") && getenv ("HOMEPATH"))
        { ConfigStore::loadConfig (QString (getenv("HOMESHARE")) + QString(getenv("HOMEPATH") + QString (QString(QDir::separator()) + ".pwsrc"))); }
    else if (getenv("HOMEDRIVE") && getenv ("HOMEPATH"))
        { ConfigStore::loadConfig (QString (getenv("HOMEDRIVE")) + QString(getenv("HOMEPATH") + QString (QString(QDir::separator()) + ".pwsrc"))); }
    else if (getenv ("HOME"))
        { ConfigStore::loadConfig (QString (getenv("HOME")) + QString (QString(QDir::separator()) + ".pwsrc")); }

    ConfigStore::store["pws_hdr_last_app"] = PWS_VERSION;

    init_pws_lib(5);
    WatchDog::init();

    QApplication app(argc, argv);
    app.installEventFilter(WatchDog::watchdog);
    app.setWindowIcon(QIcon(":/images/logo.png"));

    MainWindow mainWin;

    if (!ConfigStore::store["prefs_pws_pos_x"].isEmpty())
    {
        // restore geometry
        mainWin.setGeometry (ConfigStore::store["prefs_pws_pos_x"].toInt(), 
                             ConfigStore::store["prefs_pws_pos_y"].toInt(),
                             ConfigStore::store["prefs_pws_width"].toInt(),
                             ConfigStore::store["prefs_pws_height"].toInt());
    }

    StartDialog *start = new StartDialog();

    start->show();

    // connect the StartDialog object - okClicked() event
    QObject::connect (start,    SIGNAL(okClicked(const QString &, bool)),  &mainWin, SLOT(slot_setupTree(const QString &, bool)));
    QObject::connect (&mainWin, SIGNAL(fileOpened()),  start,   SLOT(close()));
    QObject::connect (&mainWin, SIGNAL(fileOpened()), &mainWin, SLOT(show()));

    // connect the &startDialog object - cancelClicked() event
    QObject::connect (start, SIGNAL(cancelClicked()),  start,   SLOT(close()));
    QObject::connect (start, SIGNAL(cancelClicked()), &mainWin, SLOT(close()));

    // connect the &startDialog object - newClicked() event
    QObject::connect (start, SIGNAL(newClicked(const QString &)), &mainWin, SLOT(slot_newFileSubmit(const QString &)));
    QObject::connect (start, SIGNAL(newClicked(const QString &)), &mainWin, SLOT(show()));
    QObject::connect (start, SIGNAL(newClicked(const QString &)),  start,   SLOT(close()));

    QObject::connect (mainWin.handler(), SIGNAL(wrongPassphrase()), start, SLOT(slot_wrongPassphrase()));

    return app.exec();
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
