/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "entryitemdelegate.h"

/**
 * Constructs a new EntryItemDelegate object.
 *
 * @param parent - The parent widget.
 */
EntryItemDelegate::EntryItemDelegate(QObject *parent) : QItemDelegate(parent) { } 

/**
 * Creates a QLineEdit Editor for the specific entry.
 */
QWidget *EntryItemDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &, const QModelIndex &) const
{
    QLineEdit *editor = new QLineEdit(parent);
    emit openEditor();
    return editor;
}

/**
 * Fills the editor with the string of the specific entry.
 */
void EntryItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
{
    QString value = index.model()->data(index, Qt::DisplayRole).toString();

    QLineEdit *edit = static_cast<QLineEdit*>(editor);

    if (value.trimmed() != "NA")
        { edit->insert(value.trimmed()); }
}

/**
 * Writes the editor data back to the model.
 */
void EntryItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
{
    QLineEdit *edit = static_cast<QLineEdit*>(editor);
    QString value = edit->text();

    if (value.trimmed() == "")
        { value = "NA"; }

    model->setData(index, value.trimmed());
}

/**
 * Give the new geometry back to the view.
 */
void EntryItemDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option, const QModelIndex &) const
{
    editor->setGeometry(option.rect);
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
