/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef WATCHDOG_H
#define WATCHDOG_H

#include <QObject>
#include <QEvent>
#include <QWidget>
#include <QApplication>

/**
 * This class represents a simple watchdog implementation, which
 * emits a hit()-signal everytime a mouse- or keyboard event 
 * is recognized in a widget where this watchdog is installed.
 * The WatchDog itself is self-propagating. Once it is installed in
 * a widget, it installs itself in every new child widget.
 * Quite cool.
 *
 * Example usage:
 *  ---<snip>---
 *  WatchDog::init();
 *
 *  QApplication app(argc, argv);
 *  app.installEventFilter(WatchDog::watchdog);
 *  ---<snap>---
 */
class WatchDog : public QObject
{
    Q_OBJECT

    public:
        /**
         * This is the static WatchDog instance.
         */
        static WatchDog *watchdog;

        /**
         * This method must be called before installing the
         * watchdog.
         */
        static void init();

    signals:
       /**
        * This signal is emitted everytime a mouse- or
        * keyboard event is recognized.
        */
       void hit();

    protected:
        /**
         * This method is the actual event filter implementation.
         */
        bool eventFilter(QObject *obj, QEvent *event);
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
