/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef EDITENTRYITEMDIALOG_H
#define EDITENTRYITEMDIALOG_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QDialog>
#include <QTabWidget>
#include <QMessageBox>
#include "entryitem.h"
#include "editentrywidgettabgeneral.h"
#include "editentrywidgettabdetails.h"
#include "editentrywidgettabhistory.h"

class EditEntryDialog : public QDialog
{
    Q_OBJECT 

    public:
        /**
         * This dialog displays all values stored in the EntryItem object item.
         *
         * @param item - The EntryItem object to be displayed.
         */
        EditEntryDialog(EntryItem *item, QWidget *parent = 0);

        /**
         * Overridden to set the focus at m_tab_general->m_name_edt at
         * startup.
         */
        void show ();

    signals:
        /**
         * Will be emitted when any data inside the tabs changed.
         */
        void dataChanged(EntryItem*);
        
        /**
         * Will be emitted when the user selects the "cancel" button.
         */
        void canceled(EntryItem*);

        /**
         * Will be emitted when the user selects the 
         * "fetch password" button.
         */
        void fetchPwd();

        /**
         * Will be emitted when the user selects the "fetch user"
         * button.
         */
        void fetchHistory();

    protected slots:
        /**
         * This slot is called when the user selects the "ok" button and it
         * emits a dataChanged() signal if some of the values inside the
         * tabs where changed.
         */
        void slot_okClicked();

        /**
         * This slot is called when the user selects the "cancel" button. It emits
         * a canceled().
         */
        void slot_cancelClicked();

        /**
         * This slot is called whenever the data in any of the tabs was changed by the user.
         */
        void slot_dataChanged();

        /**
         * This slot is called when the user selected the "clear password history" button
         * inside the password history tab.
         */
        void slot_historyCleared();

        /**
         * This slot is called when the user selects the "fetch password" button.
         */
        void slot_fetchPwd();

    protected:
        /**
         * Synchronizes the values stored inside the tabs with the actual EntryItem object
         * that is displayed.
         */
        bool saveItem();

        /**
         * Will be set to true if any data inside the tabs was modified.
         */
        bool m_data_changed;

        /**
         * Will be set to true if the user requested clearing the password
         * .history
         */
        bool m_history_cleared;

        /**
         * The child widgets.
         */
        EditEntryWidgetTabGeneral *m_tab_general;
        EditEntryWidgetTabDetails *m_tab_details;
        EditEntryWidgetTabHistory *m_tab_history;

        QGridLayout *m_grid;
        QTabWidget  *m_tab;

        QPushButton *m_ok_btn;
        QPushButton *m_cancel_btn;

        EntryItem *m_item;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
