/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef EDITENTRYITEMWIDGETTABDETAILS_H
#define EDITENTRYITEMWIDGETTABDETAILS_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QGroupBox>
#include <QCheckBox>
#include <QSpinBox>
#include "configstore.h"
#include "entryitem.h"

class EditEntryWidgetTabDetails : public QWidget
{
    Q_OBJECT 

    public:
        /**
         * This widget displays the password policy settings and the
         * timestamps for the EntryItem object item.
         *
         * @param item - The EntryItem object to be displayed.
         */
        EditEntryWidgetTabDetails(EntryItem *item, QWidget *parent = 0);

    signals:
        /**
         * This signal will be emitted whenever any data inside this widget
         * is changed.
         */
        void dataChanged();

    protected slots:
        /**
         * This slot will be called when the user selects the "use only hex characters"
         * checkbox and unchecks all other password policy checkboxes.
         */
        void slot_hexChkStateChanged(int state);

        /**
         * This slot will be called when the user selects any other than the "use only hex characters"
         * password policy checkbox and unchecks the "use only hex characters" checkbox.
         */
        void slot_otherChkStateChanged(int state);

    protected:
        /**
         * Creates the timestamp groupbox.
         */
        void createDateGroup(EntryItem *item);

        /**
         * Creates the uuid groupbox.
         */
        void createUuidGroup(EntryItem *item);

        /**
         * Creates the password policy group box.
         */
        void createPwdPolicyGroup();

        /**
         * Private child widgets.
         */
        QLabel *m_mtime_lbl;
        QLabel *m_pwd_mtime_lbl;
        QLabel *m_ctime_lbl;
        QLabel *m_pwd_length_lbl;
        QLabel *m_atime_lbl;

        QLabel *m_mtime_dat;
        QLabel *m_pwd_mtime_dat;
        QLabel *m_ctime_dat;
        QLabel *m_atime_dat;
        QLabel *m_uuid_dat;

        QCheckBox *m_lower_case_chk;
        QCheckBox *m_upper_case_chk;
        QCheckBox *m_digits_chk;
        QCheckBox *m_symbols_chk;
        QCheckBox *m_easy_chk;
        QCheckBox *m_hex_chk;

        QSpinBox *m_pwd_length_spin;

        QGroupBox   *m_date_box;
        QGroupBox   *m_uuid_box;
        QGroupBox   *m_pwd_policy_box;

        QGridLayout *m_date_grid;
        QGridLayout *m_pwd_policy_grid;
        QVBoxLayout *m_uuid_vbox;
        QVBoxLayout *m_vbox;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
