/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "editentrywidgettabgeneral.h"

/**
 * This widget display the most relevant informtion stored inside the
 * EntryItem object item.
 *
 * @param item - The EntryItem object to be displayed.
 */
EditEntryWidgetTabGeneral::EditEntryWidgetTabGeneral(EntryItem *item, QWidget *parent) : QWidget(parent)
{   
    m_pwd = new QString();

    // setup the child widgets
    m_name_lbl  = new QLabel(tr("Name: "));
    m_user_lbl  = new QLabel(tr("User: "));
    m_pwd_lbl   = new QLabel(tr("Password: "));
    m_notes_lbl = new QLabel(tr("Notes: "));
    m_url_lbl   = new QLabel(tr("Url: "));

    m_name_edt = new QLineEdit(item->getName());
    m_user_edt = new QLineEdit(item->getUser());
    m_pwd_edt  = new QLineEdit("          ");
    m_url_edt  = new QLineEdit(item->getUrl().toString());
    *m_pwd = item->getPwd();

    if (ConfigStore::store["pws_hdr_version"].startsWith("2"))
    {
        // not supported in PWSv2 format
        m_url_edt->setDisabled (true);
    }

    m_notes_edt = new QTextEdit();
    m_notes_edt->setAcceptRichText (false);
    m_notes_edt->setMinimumWidth (350);
    m_notes_edt->setPlainText (item->getNotes());

    m_gen_btn   = new QPushButton(tr("&Generate"));
    m_fetch_btn = new QPushButton(tr("&Fetch"));

    if (ConfigStore::store["prefs_bool_showpwdefault"] == "1")
    {
        m_pwd_edt->setText(*m_pwd);
        m_pwd_edt->setEchoMode (QLineEdit::Normal); 
        m_show_btn = new QPushButton(tr("&Hide"));
    }
    else
    {
        m_pwd_edt->setEchoMode (QLineEdit::Password); 
        m_show_btn  = new QPushButton(tr("&Show"));
    }

    // buttons should always have a fixed size
    m_show_btn->setMinimumWidth  (100);
    m_show_btn->setMaximumWidth  (100);
    m_fetch_btn->setMinimumWidth (100);
    m_fetch_btn->setMaximumWidth (100);
    m_gen_btn->setMinimumWidth   (100);
    m_gen_btn->setMaximumWidth   (100);

    // setup the layout
    m_grid = new QGridLayout();
    m_grid->addWidget (m_name_lbl,   0,0);
    m_grid->addWidget (m_name_edt,   0,1);
    m_grid->addWidget (m_show_btn,   0,2);
    m_grid->addWidget (m_user_lbl,   1,0);
    m_grid->addWidget (m_user_edt,   1,1);
    m_grid->addWidget (m_fetch_btn,  1,2);
    m_grid->addWidget (m_pwd_lbl,    2,0);
    m_grid->addWidget (m_pwd_edt,    2,1);
    m_grid->addWidget (m_gen_btn,    2,2);
    m_grid->addWidget (m_url_lbl,    3,0);
    m_grid->addWidget (m_url_edt,    3,1, 1,2);
    m_grid->addWidget (m_notes_edt,  5,0, 2,3);

    m_grid->setRowStretch (0, 0); 
    m_grid->setRowStretch (1, 0); 
    m_grid->setRowStretch (2, 0); 
    m_grid->setRowStretch (3, 0); 
    m_grid->setRowStretch (4, 0); 
    m_grid->setRowStretch (5, 255); 

    setLayout(m_grid);
    
    // data changed
    connect (m_name_edt, SIGNAL(textChanged(const QString)), this, SIGNAL(dataChanged()));
    connect (m_user_edt, SIGNAL(textChanged(const QString)), this, SIGNAL(dataChanged()));
    connect (m_pwd_edt,  SIGNAL(textChanged(const QString)), this, SIGNAL(dataChanged()));
    connect (m_url_edt,  SIGNAL(textChanged(const QString)), this, SIGNAL(dataChanged()));
    connect (m_name_edt, SIGNAL(textEdited(const QString)),  this, SIGNAL(dataChanged()));
    connect (m_user_edt, SIGNAL(textEdited(const QString)),  this, SIGNAL(dataChanged()));
    connect (m_pwd_edt,  SIGNAL(textEdited(const QString)),  this, SIGNAL(dataChanged()));
    connect (m_url_edt,  SIGNAL(textEdited(const QString)),  this, SIGNAL(dataChanged()));

    connect (m_notes_edt, SIGNAL(textChanged()), this, SIGNAL(dataChanged()));

    // buttons
    connect (m_show_btn,  SIGNAL(clicked(bool)), this, SLOT(slot_showClicked()));
    connect (m_gen_btn,   SIGNAL(clicked(bool)), this, SLOT(slot_genClicked()));
    connect (m_fetch_btn, SIGNAL(clicked(bool)), this, SIGNAL(fetchClicked()));

    if (ConfigStore::store["readonly"] == "1")
    {
        m_name_edt->setReadOnly(true);
        m_user_edt->setReadOnly(true);
        m_pwd_edt->setReadOnly(true);
        m_url_edt->setReadOnly(true);
        m_notes_edt->setReadOnly(true);
    }

    connect (m_pwd_edt, SIGNAL(textChanged(const QString &)), this, SLOT(slot_pwdChanged(const QString &)));
    connect (m_pwd_edt, SIGNAL(textEdited(const QString &)),  this, SLOT(slot_pwdChanged(const QString &)));

    // initialize the random number generator
    // well, predictable, i know, but i think it is ok
    // for our purposes
    srand (time(NULL));

    if (item->getUser() == "" && item->getPwd() == "" && item->getNotes() == "" && item->getUrl() == QUrl(""))
    {
        m_pwd_edt->setEchoMode (QLineEdit::Normal);
        m_show_btn->setText ("&Hide");
        slot_genClicked();
    }

    // create the focus chain
    setTabOrder (m_name_edt, m_user_edt);
    setTabOrder (m_user_edt, m_pwd_edt);
    setTabOrder (m_pwd_edt,  m_url_edt);
    setTabOrder (m_url_edt,  m_notes_edt);
}


/**
 * Set the active focus to m_name_edt.
 */
void EditEntryWidgetTabGeneral::setNameFocus ()
{
    m_name_edt->setFocus(Qt::OtherFocusReason);
    m_name_edt->deselect();
}

/**
 * Deletes m_pwd.
 */
EditEntryWidgetTabGeneral::~EditEntryWidgetTabGeneral()
{
    delete m_pwd;
}

/**
 * Check whether c is a easy-to-read character or not.
 *
 * @param c - The character to be checked.
 *
 * @returns true if the character is easy to read, otherwise false.
 */
bool EditEntryWidgetTabGeneral::isEasyChar(QChar c)
{
    char invalid[] = { 'l', 'I', '1', '0', 'O', 'S', '5', 'Z', '2' };

    for (unsigned int i = 0; i < sizeof(invalid); i++)
    {
        if (c == invalid[i]) return false;
    }
    
    return true;
}

/**
 * This slot is called when the user selects the "generate" button and it
 * generates a new random password comforming to the current password policy.
 */
void EditEntryWidgetTabGeneral::slot_genClicked()
{
    int len = ConfigStore::store["prefs_int_pwlendefault"].toInt();
    int count = 0;

    *m_pwd = "";
    while (count != len)
    {
        QChar rnd = QChar::fromAscii(((unsigned char)rand())/2);
        if (ConfigStore::store["prefs_bool_pwusehexdigit"] == "1")
        {
            *m_pwd += QString::number (rand(), 16).right(1);
            count++;
        }
        else if (ConfigStore::store["prefs_bool_pweasyvision"] == "1" && isEasyChar(rnd))
        {
            if (ConfigStore::store["prefs_bool_pwuselowercase"] == "1" && rnd.isLower())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
            else if (ConfigStore::store["prefs_bool_pwuseuppercase"] == "1" && rnd.isUpper())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
            else if (ConfigStore::store["prefs_bool_pwusedigits"] == "1" && rnd.isNumber())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
            else if (ConfigStore::store["prefs_bool_pwusesysmbols"] == "1" && rnd.isSymbol())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
        }
        else if (ConfigStore::store["prefs_bool_pweasyvision"] == "0")
        {
            if (ConfigStore::store["prefs_bool_pwuselowercase"] == "1" && rnd.isLower())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
            else if (ConfigStore::store["prefs_bool_pwuseuppercase"] == "1" && rnd.isUpper())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
            else if (ConfigStore::store["prefs_bool_pwusedigits"] == "1" && rnd.isNumber())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
            else if (ConfigStore::store["prefs_bool_pwusesysmbols"] == "1" && rnd.isSymbol())
            {
               *m_pwd += rnd.toAscii();
               count++;
            }
        }
    }

    if (m_pwd_edt->echoMode() != QLineEdit::Password)
    {
        m_pwd_edt->setText(*m_pwd);
    }

    emit dataChanged();
}

/**
 * This slot is called whenever the password is changed.
 */
void EditEntryWidgetTabGeneral::slot_pwdChanged (const QString &pwd)
{
    if (pwd != "          ")
        { *m_pwd = pwd; }
}

/**
 * This slot is called when the user selects the "show" button and
 * it shows/hides the current password.
 * If the password is hidden, the password set inside the QLineEdit field
 * is set to 10 space characters to ensure that the actual length of the password
 * is not predictable.
 */
void EditEntryWidgetTabGeneral::slot_showClicked()
{
    if (m_pwd_edt->echoMode() == QLineEdit::Password)
    { 
        m_pwd_edt->setText(*m_pwd);
        m_pwd_edt->setEchoMode (QLineEdit::Normal); 
        m_show_btn->setText ("&Hide");
    }
    else
    { 
        m_pwd_edt->setText("          ");
        m_pwd_edt->setEchoMode (QLineEdit::Password); 
        m_show_btn->setText ("&Show");
    }
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
