/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef EDITENTRYITEMWIDGETTABGENERAL_H
#define EDITENTRYITEMWIDGETTABGENERAL_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include "configstore.h"
#include "entryitem.h"

class EditEntryWidgetTabGeneral : public QWidget
{
    Q_OBJECT 

    public:
        /**
         * This widget display the most relevant informtion stored inside the
         * EntryItem object item.
         *
         * @param item - The EntryItem object to be displayed.
         */
        EditEntryWidgetTabGeneral(EntryItem *item, QWidget *parent = 0);

        /**
         * Deletes m_pwd.
         */
        ~EditEntryWidgetTabGeneral();

        /**
         * Public child widgeds that will be read by EditEntryDialog.
         */
        QLineEdit *m_name_edt;
        QLineEdit *m_user_edt;
        QLineEdit *m_url_edt;
        QTextEdit *m_notes_edt;
        QString *m_pwd;


        /**
         * Set the active focus to m_name_edt.
         */
        void setNameFocus ();

    protected slots:

        /**
         * This slot is called when the user selects the "show" button and
         * it shows/hides the current password.
         * If the password is hidden, the password set inside the QLineEdit field
         * is set to 10 space characters to ensure that the actual length of the password
         * is not predictable.
         */
        void slot_showClicked();

        /**
         * This slot is called when the user selects the "generate" button and it
         * generates a new random password comforming to the current password policy.
         */
        void slot_genClicked();

        /**
         * This slot is called whenever the password is changed.
         */
        void slot_pwdChanged (const QString &pwd);

    signals:
        /**
         * This signal is emitted whenever data changed inside this tab.
         */
        void dataChanged();

        /**
         * This signal is emitted when the user selects the "fetch password" button.
         */
        void fetchClicked();

    protected:
        /**
         * Check whether c is a easy-to-read character or not.
         *
         * @param c - The character to be checked.
         *
         * @returns true if the character is easy to read, otherwise false.
         */
        bool isEasyChar(QChar c);

        /**
         * Private child widgets.
         */
        QLabel *m_name_lbl;
        QLabel *m_user_lbl;
        QLabel *m_pwd_lbl;
        QLabel *m_url_lbl;
        QLabel *m_notes_lbl;

        QLineEdit *m_pwd_edt;

        QPushButton *m_show_btn;
        QPushButton *m_fetch_btn;
        QPushButton *m_gen_btn;

        QGridLayout *m_grid;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
