/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef EDITENTRYITEMWIDGETTABHISTORY_H
#define EDITENTRYITEMWIDGETTABHISTORY_H

#include <QWidget>
#include <QTableWidget>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QGroupBox>
#include <QCheckBox>
#include <QSpinBox>
#include <QVBoxLayout>
#include <QHeaderView>
#include <QDateTime>
#include <QList>
#include "configstore.h"
#include "entryitem.h"

class EditEntryWidgetTabHistory : public QWidget
{
    Q_OBJECT 

    public:
        /**
         * This widget displays the passowrd history stored in the EntryItem object item.
         *
         * @param item - The EntryItem object containing the password history that should be
         *               displayed.
         */
        EditEntryWidgetTabHistory(EntryItem *item, QWidget *parent = 0);

        /**
         * Public child widgets that will be read inside EditEntryDialog.
         */
        QCheckBox *m_save_history_chk;
        QSpinBox  *m_numpwd_spn;

    signals:
        /**
         * This signal will be emitted if the data inside this
         * widget chages.
         */
        void dataChanged();

        /**
         * This signal will be emitted when the user selects
         * the "clear" button.
         */
        void clearClicked();

        /**
         * This signal will be emitted when the user selects
         * the "fetch" button.
         */
        void fetchHistory();

    protected:
        /**
         * Private child widgets.
         */
        QGridLayout  *m_options_grid;
        QGridLayout  *m_grid;

        QTableWidget *m_table;

        QGroupBox *m_options_box;

        QPushButton *m_clear_btn;
        QPushButton *m_copy_btn;

        QLabel *m_numpwd_lbl;

    protected slots:
        /**
         * This slot is called when the user selects the "clear" button.
         * It clears the password history and emitts a clearClicked signal.
         */
        void slot_clearClicked();

        /**
         * This slot is called when the user selects the "save password history" checkbox and
         * enables, resp. disables the password history feature.
         */
        void slot_saveHistoryClicked();
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
