/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "informationdialog.h"

/**
 * This dialog shows informations stored inside the database header.
 */
InformationDialog::InformationDialog(PWSTreeModel * model, QWidget *parent) : QDialog(parent)
{   
    setAttribute (Qt::WA_DeleteOnClose, true);

    // create the child widgets
    m_uuid_lbl      = new QLabel(tr("Uuid: "));
    m_last_uid_lbl  = new QLabel(tr("Last author: "));
    m_last_mod_lbl  = new QLabel(tr("Last modification time: "));
    m_last_app_lbl  = new QLabel(tr("Passwordsafe was last saved by: "));
    m_last_host_lbl = new QLabel(tr("Passwordsafe was last saved on host: "));
    m_db_name_lbl   = new QLabel(tr("Database name: "));
    m_db_desc_lbl   = new QLabel(tr("Database description: "));
    m_ver_lbl       = new QLabel(tr("Database format version: "));
    m_num_groups_lbl = new QLabel(tr("Number of groups: "));
    m_num_entries_lbl = new QLabel(tr("Number of password entries: "));

    m_uuid_inf      = new QLabel(ConfigStore::store["pws_hdr_uuid"]);
    m_last_uid_inf  = new QLabel(ConfigStore::store["pws_hdr_last_uid"]);
    m_last_app_inf  = new QLabel(ConfigStore::store["pws_hdr_last_app"]);
    m_last_host_inf = new QLabel(ConfigStore::store["pws_hdr_last_host"]);
    m_db_name_edt   = new QLineEdit(ConfigStore::store["pws_hdr_db_name"]);
    m_db_desc_edt   = new QLineEdit(ConfigStore::store["pws_hdr_db_desc"]);
    m_ver_inf       = new QLabel(ConfigStore::store["pws_hdr_version"]);
    m_num_groups_inf   = new QLabel(QString::number(model->numGroups()));
    m_num_entries_inf = new QLabel(QString::number(model->numEntries()));

    if (ConfigStore::store["pws_hdr_last_modified"] != "0")
    { 
        time_t     last_mod = ConfigStore::store["pws_hdr_last_modified"].toLong();
        QDateTime qlast_mod = QDateTime::fromTime_t (last_mod);
        m_last_mod_inf = new QLabel(qlast_mod.toString(ConfigStore::store["prefs_pws_date_format"])); 
    }
    else
        { m_last_mod_inf  = new QLabel(""); }

    m_ok_btn     = new QPushButton (tr("&Ok"));
    m_cancel_btn = new QPushButton (tr("&Cancel"));

    // buttons sould always have a fixed size
    m_ok_btn->setMinimumWidth  (120);
    m_ok_btn->setMaximumWidth  (120);
    m_cancel_btn->setMinimumWidth  (120);
    m_cancel_btn->setMaximumWidth  (120);

    // setup the layout
    m_grid = new QGridLayout();
    m_grid->addWidget (m_uuid_lbl,      0,0);
    m_grid->addWidget (m_uuid_inf,      0,1);
    m_grid->addWidget (m_last_uid_lbl,  1,0);
    m_grid->addWidget (m_last_uid_inf,  1,1);
    m_grid->addWidget (m_last_mod_lbl,  2,0);
    m_grid->addWidget (m_last_mod_inf,  2,1);
    m_grid->addWidget (m_last_app_lbl,  3,0);
    m_grid->addWidget (m_last_app_inf,  3,1);
    m_grid->addWidget (m_last_host_lbl, 4,0);
    m_grid->addWidget (m_last_host_inf, 4,1);
    m_grid->addWidget (m_db_name_lbl,   5,0);
    m_grid->addWidget (m_db_name_edt,   5,1);
    m_grid->addWidget (m_db_desc_lbl,   6,0);
    m_grid->addWidget (m_db_desc_edt,   6,1);
    m_grid->addWidget (m_ver_lbl,       7,0);
    m_grid->addWidget (m_ver_inf,       7,1);
    m_grid->addWidget (m_num_groups_lbl, 8,0);
    m_grid->addWidget (m_num_groups_inf, 8,1);
    m_grid->addWidget (m_num_entries_lbl, 9,0);
    m_grid->addWidget (m_num_entries_inf, 9,1);

    QString curfile = ConfigStore::store["curfile"];
    curfile.replace (QRegExp (".*/"), "");

    m_box = new QGroupBox(curfile);
    m_box->setLayout (m_grid);

    m_main_grid = new QGridLayout();
    m_main_grid->addWidget (m_box, 0,0, 1,3);
    m_main_grid->addWidget (m_cancel_btn, 1,1);
    m_main_grid->addWidget (m_ok_btn, 1,2);

    if (ConfigStore::store["pws_hdr_version"].startsWith("2"))
    {
        // not supported in PWSv2
        m_db_name_edt->setDisabled (true);
        m_db_desc_edt->setDisabled (true);
    }

    setLayout (m_main_grid);
    setWindowTitle (curfile);

    // connect the buttons
    connect (m_ok_btn,     SIGNAL(clicked(bool)), this, SLOT(slot_okClicked()));
    connect (m_cancel_btn, SIGNAL(clicked(bool)), this, SLOT(slot_cancelClicked()));
}

/**
 * This slot is called when the user selects the "ok" button.
 */
void InformationDialog::slot_okClicked ()
{
    bool changed = false;

    if (ConfigStore::store["pws_hdr_db_name"] != m_db_name_edt->text())
        { ConfigStore::store["pws_hdr_db_name"] = m_db_name_edt->text(); changed = true; }

    if (ConfigStore::store["pws_hdr_db_desc"] != m_db_desc_edt->text())
        { ConfigStore::store["pws_hdr_db_desc"] = m_db_desc_edt->text(); changed = true; }

    if (changed)
        { emit submit (); }
    close();
}

/**
 * This slot is called when the user selects the "cancel" button.
 */
void InformationDialog::slot_cancelClicked ()
{
    close();
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
