/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "newpassphrasedialog.h"

/**
 * This dialog is used to request a new passphrase from the user.
 */
NewPassphraseDialog::NewPassphraseDialog(QWidget *parent) : QDialog(parent)
{   
    setAttribute (Qt::WA_DeleteOnClose, true);

    // create the child widgets
    m_pwd_lbl_one = new QLabel(tr("Enter passphrase:"));
    m_pwd_lbl_two = new QLabel(tr("Verify passphrase:"));
    m_pwd_edt_one = new QLineEdit();
    m_pwd_edt_two = new QLineEdit();
    m_ok_btn      = new QPushButton (tr("&Ok"));
    m_cancel_btn  = new QPushButton (tr("&Cancel"));

    m_pwd_edt_one->setEchoMode (QLineEdit::Password);
    m_pwd_edt_two->setEchoMode (QLineEdit::Password);

    // buttons should always have a fixed size
    m_ok_btn->setMinimumWidth  (120);
    m_ok_btn->setMaximumWidth  (120);
    m_cancel_btn->setMinimumWidth  (120);
    m_cancel_btn->setMaximumWidth  (120);

    // setup the layout
    m_grid = new QGridLayout();
    m_grid->addWidget (m_pwd_lbl_one,    0,0 ,1,2);
    m_grid->addWidget (m_pwd_edt_one,    1,0 ,1,2);
    m_grid->addWidget (m_pwd_lbl_two,    2,0 ,1,2);
    m_grid->addWidget (m_pwd_edt_two,    3,0 ,1,2);
    m_grid->addWidget (m_cancel_btn, 4,0);
    m_grid->addWidget (m_ok_btn,     4,1);

    setLayout (m_grid);
    setWindowTitle (tr("Enter passphrase"));

    // connect the buttons
    connect (m_ok_btn,     SIGNAL(clicked(bool)), this, SLOT(slot_okClicked()));
    connect (m_cancel_btn, SIGNAL(clicked(bool)), this, SLOT(slot_cancelClicked()));

    // ensure that enter == slot_okClicked
    (void) new QShortcut(Qt::Key_Enter,  this, SLOT(slot_okClicked()));
    (void) new QShortcut(Qt::Key_Return, this, SLOT(slot_okClicked()));
}

/**
 * This slot is called when the user selects the "ok" button.
 */
void NewPassphraseDialog::slot_okClicked ()
{
    if (m_pwd_edt_one->text() == "" && m_pwd_edt_two->text() == "")
    {
        // empty passphrase not possible
        QMessageBox::critical(this, tr("Error"), tr("Empty passphrase is not possible.")); return;
    }
    else if (m_pwd_edt_one->text() !=  m_pwd_edt_two->text())
    {
        QMessageBox::critical(this, tr("Error"), tr("Passwords are different.")); return;
    }
    else
    {
        emit submit (m_pwd_edt_one->text());
        close();
    }
}

/**
 * This slot is called when the user selects the "cancel" button.
 */
void NewPassphraseDialog::slot_cancelClicked ()
{
    close();
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
