/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef NEWPASSPHRASEDIALOG_H
#define NEWPASSPHRASEDIALOG_H

#include <QWidget>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include <QGridLayout>
#include <QMessageBox>
#include <QDialog>
#include <QShortcut>
#include <iostream>
#include "configstore.h"
#include "pwshandler.h"

class NewPassphraseDialog : public QDialog
{
    Q_OBJECT 

    public:
        /**
         * This dialog is used to request a new passphrase from the user.
         */
        NewPassphraseDialog(QWidget *parent = 0);

    signals:
        /**
         * This signal is emitted when a passphrase was given and 
         * the "ok" button was clicked.
         *
         * @param passphrase - The passphrase.
         */
        void submit (const QString & passphrase);

    protected:
        /**
         * The child widgets.
         */
        QGridLayout *m_grid;

        QLineEdit   *m_pwd_edt_one;
        QLineEdit   *m_pwd_edt_two;

        QLabel      *m_pwd_lbl_one;
        QLabel      *m_pwd_lbl_two;

        QPushButton *m_ok_btn;
        QPushButton *m_cancel_btn;

    public slots:
        /**
         * This slot is called when the user selects the "ok" button.
         */
        void slot_okClicked ();

        /**
         * This slot is called when the user selects the "cancel" button.
         */
        void slot_cancelClicked ();
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
