/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "passphrasedialog.h"

/**
 * This widget represents a simple passphrase dialog.
 */
PassphraseDialog::PassphraseDialog(bool showReadOnly, QWidget *parent) : QDialog(parent)
{   
    setAttribute (Qt::WA_DeleteOnClose, true);

    m_showReadOnly = showReadOnly;

    // create the child widgets
    m_pwd_lbl    = new QLabel(tr("Enter passphrase:"));
    m_pwd_edt    = new QLineEdit();
    m_ok_btn     = new QPushButton (tr("&Ok"));
    m_cancel_btn = new QPushButton (tr("&Cancel"));

    m_pwd_edt->setEchoMode (QLineEdit::Password);

    m_readonly_chk = new QCheckBox (tr("Open readonly"));

    // buttons should always have a fixed size
    m_ok_btn->setMinimumWidth  (120);
    m_ok_btn->setMaximumWidth  (120);
    m_cancel_btn->setMinimumWidth  (120);
    m_cancel_btn->setMaximumWidth  (120);

    // setup the layout
    m_grid = new QGridLayout();
    m_grid->addWidget (m_pwd_lbl,    0,0 ,1,2);
    m_grid->addWidget (m_pwd_edt,    1,0 ,1,2);
    m_grid->addWidget (m_readonly_chk, 2,0);
    m_grid->addWidget (m_cancel_btn, 3,0);
    m_grid->addWidget (m_ok_btn,     3,1);

    setLayout (m_grid);
    setWindowTitle (tr("Enter passphrase"));

    if (!m_showReadOnly)
    {
        m_readonly_chk->hide();
    }

    // connect the buttons
    connect (m_ok_btn,     SIGNAL(clicked(bool)), this, SLOT(slot_okClicked()));
    connect (m_cancel_btn, SIGNAL(clicked(bool)), this, SLOT(slot_cancelClicked()));

    // ensure that enter == slot_okClicked
    (void) new QShortcut(Qt::Key_Enter,  this, SLOT(slot_okClicked()));
    (void) new QShortcut(Qt::Key_Return, this, SLOT(slot_okClicked()));
}

/**
 * This slot is called when the user selects the "ok" button.
 */
void PassphraseDialog::slot_okClicked ()
{
    if (m_pwd_edt->text() == "")
    {
        // empty passphrase not possible
        QMessageBox::critical(this, tr("Error"), tr("Empty passphrase is not possible.")); return;
        return;
    }

    if (m_readonly_chk->checkState() == Qt::Checked && m_showReadOnly)
        { emit submit(m_pwd_edt->text(), true); }
    else if (m_showReadOnly)
        { emit submit(m_pwd_edt->text(), false); }
    else
        { emit submit(m_pwd_edt->text(), false); }
}

/**
 * This slot is called when the user selects the "cancel" button.
 */
void PassphraseDialog::slot_cancelClicked ()
{
    close();
}

/**
 * This slot is called when the user entered a wrong passphrase.
 */
void PassphraseDialog::slot_wrongPassphrase()
{
    m_pwd_edt->selectAll();
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
