/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PASSPHRASEDIALOG_H
#define PASSPHRASEDIALOG_H

#include <QWidget>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include <QGridLayout>
#include <QMessageBox>
#include <QCheckBox>
#include <QDialog>
#include <QShortcut>
#include <iostream>
#include "configstore.h"
#include "pwshandler.h"

class PassphraseDialog : public QDialog
{
    Q_OBJECT 

    public:
        /**
         * This widget represents a simple passphrase dialog.
         */
        PassphraseDialog(bool showReadOnly = true, QWidget *parent = 0);

    signals:
        /**
         * This signal is emitted when a passphrase was given and 
         * the "ok" button was clicked.
         *
         * @param passphrase - The passphrase.
         * @param readonly - True if the readonly checkbox was checked, otherwise false.
         */
        void submit (const QString & passphrase, bool readonly);

    protected:
        /**
         * The child widgets.
         */
        QGridLayout *m_grid;

        QLineEdit   *m_pwd_edt;;

        QLabel      *m_pwd_lbl;

        QPushButton *m_ok_btn;
        QPushButton *m_cancel_btn;

        QCheckBox *m_readonly_chk;

        /**
         * If set to true, the readonly check box will
         * be available.
         */
        bool m_showReadOnly;

    public slots:
        /**
         * This slot is called when the user selects the "ok" button.
         */
        void slot_okClicked ();

        /**
         * This slot is called when the user selects the "cancel" button.
         */
        void slot_cancelClicked ();

        /**
         * This slot is called when the user entered a wrong passphrase.
         */
        void slot_wrongPassphrase();
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
