/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "preferencesdialog.h"

/**
 * This dialog implements the preferences window.
 */
PreferencesDialog::PreferencesDialog(QWidget *parent) : QDialog(parent)
{   
    setAttribute (Qt::WA_DeleteOnClose, true);

    m_data_changed  = false;
    m_prefs_changed = false;

    // create the child widgets
    m_tab_general = new PreferencesWidgetTabGeneral(); // general preferences
    m_tab_policy  = new PreferencesWidgetTabPolicy();  // password policy
    m_tab_misc    = new PreferencesWidgetTabMisc();    // backup settings

    m_tab = new QTabWidget(this);
    m_tab->addTab (m_tab_general, "&General settings");
    m_tab->addTab (m_tab_policy, "&Password policy");
    m_tab->addTab (m_tab_misc, "&Miscellaneous");

    m_ok_btn     = new QPushButton (tr("&Ok"));
    m_cancel_btn = new QPushButton (tr("&Cancel"));

    // ansure that buttons always have a fixed size
    m_ok_btn->setMinimumWidth  (120);
    m_ok_btn->setMaximumWidth  (120);
    m_cancel_btn->setMinimumWidth  (120);
    m_cancel_btn->setMaximumWidth  (120);

    // setup the layout
    m_grid = new QGridLayout();
    m_grid->addWidget (m_tab, 0,0,1,3);
    m_grid->addWidget (m_cancel_btn, 1,1);
    m_grid->addWidget (m_ok_btn, 1,2);

    setLayout(m_grid);
    setWindowTitle (tr("Preferences"));

    // and connect the buttons
    connect (m_ok_btn,     SIGNAL(clicked(bool)), this, SLOT(slot_okClicked()));
    connect (m_cancel_btn, SIGNAL(clicked(bool)), this, SLOT(slot_cancelClicked()));
}

/**
 * This method synchronizes the general preferences with the ConfigStore.
 */
void PreferencesDialog::syncGeneralPrefs()
{
    if (m_tab_general->m_timestamps_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_maintaindatetimestamps"] != "0")
    {
        ConfigStore::store["prefs_bool_maintaindatetimestamps"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_general->m_timestamps_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_bool_maintaindatetimestamps"] != "1")
    {
        ConfigStore::store["prefs_bool_maintaindatetimestamps"] = "1";
        m_data_changed = true;
    }

    if (m_tab_general->m_confirm_clpbrd_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_pws_confirm_clpbrd"] != "0")
    {
        ConfigStore::store["prefs_pws_confirm_clpbrd"] = "0";
        m_prefs_changed = true;
    }
    else if(m_tab_general->m_confirm_clpbrd_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_pws_confirm_clpbrd"] != "1")
    {
        ConfigStore::store["prefs_pws_confirm_clpbrd"] = "1";
        m_prefs_changed = true;
    }

    if (m_tab_general->m_save_immediately_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_saveimmediately"] != "0")
    {
        ConfigStore::store["prefs_bool_saveimmediately"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_general->m_save_immediately_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_bool_saveimmediately"] != "1")
    {
        ConfigStore::store["prefs_bool_saveimmediately"] = "1";
        m_data_changed = true;
    }

    if (m_tab_general->m_confirm_del_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_pws_confirm_delete"] != "0")
    {
        ConfigStore::store["prefs_pws_confirm_delete"] = "0";
        m_prefs_changed = true;
    }
    else if(m_tab_general->m_confirm_del_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_pws_confirm_delete"] != "1")
    {
        ConfigStore::store["prefs_pws_confirm_delete"] = "1";
        m_prefs_changed = true;
    }

    if (m_tab_general->m_idle_timeout_spn->cleanText() != ConfigStore::store["prefs_int_idletimeout"])
    {
        ConfigStore::store["prefs_int_idletimeout"] = m_tab_general->m_idle_timeout_spn->cleanText();
        m_data_changed = true;
    }

    if (m_tab_general->m_clpbrd_timeout_spn->cleanText() != ConfigStore::store["prefs_pws_clpbrd_timeout"])
    {
        ConfigStore::store["prefs_pws_clpbrd_timeout"] = m_tab_general->m_clpbrd_timeout_spn->cleanText();
        m_prefs_changed = true;
    }

    if (m_tab_general->m_maxrecent_files_spn->cleanText() != ConfigStore::store["prefs_pws_maxrecentfiles"])
    {
        ConfigStore::store["prefs_pws_maxrecentfiles"] = m_tab_general->m_maxrecent_files_spn->cleanText();
        m_prefs_changed = true;
    }

    if(m_tab_general->m_idle_timeout_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_pws_enable_idle_timeout"] != "1")
    {
        ConfigStore::store["prefs_pws_enable_idle_timeout"] = "1";
        m_prefs_changed = true;
    }
    else if(m_tab_general->m_idle_timeout_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_pws_enable_idle_timeout"] != "0")
    {
        ConfigStore::store["prefs_pws_enable_idle_timeout"] = "0";
        m_prefs_changed = true;
    }
}

/**
 * This method synchronizes the password policy preferences with the ConfigStore.
 */
void PreferencesDialog::syncPwdPolicy()
{
    // password policy box
    if (m_tab_policy->m_hex_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_pwusehexdigit"] != "0")
    {
        ConfigStore::store["prefs_bool_pwusehexdigit"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_hex_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_pwusehexdigit"] != "1")
    {
        ConfigStore::store["prefs_bool_pwusehexdigit"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_easy_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_pweasyvision"] != "0")
    {
        ConfigStore::store["prefs_bool_pweasyvision"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_easy_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_pweasyvision"] != "1")
    {
        ConfigStore::store["prefs_bool_pweasyvision"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_lower_case_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_pwuselowercase"] != "0")
    {
        ConfigStore::store["prefs_bool_pwuselowercase"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_lower_case_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_pwuselowercase"] != "1")
    {
        ConfigStore::store["prefs_bool_pwuselowercase"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_upper_case_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_pwuseuppercase"] != "0")
    {
        ConfigStore::store["prefs_bool_pwuseuppercase"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_upper_case_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_pwuseuppercase"] != "1")
    {
        ConfigStore::store["prefs_bool_pwuseuppercase"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_digits_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_pwusedigits"] != "0")
    {
        ConfigStore::store["prefs_bool_pwusedigits"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_digits_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_pwusedigits"] != "1")
    {
        ConfigStore::store["prefs_bool_pwusedigits"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_symbols_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_pwusesysmbols"] != "0")
    {
        ConfigStore::store["prefs_bool_pwusesysmbols"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_symbols_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_pwusesysmbols"] != "1")
    {
        ConfigStore::store["prefs_bool_pwusesysmbols"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_pwd_length_spin->cleanText() != ConfigStore::store["prefs_int_pwlendefault"])
    {
        ConfigStore::store["prefs_int_pwlendefault"] = m_tab_policy->m_pwd_length_spin->cleanText();
        m_data_changed = true;
    }
}

/**
 * This method synchronizes the password history settings with the ConfigStore.
 */
void PreferencesDialog::syncPwdHistory()
{
    // password history box
    if (m_tab_policy->m_save_pwd_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_savepasswordhistory"] != "0")
    {
        ConfigStore::store["prefs_bool_savepasswordhistory"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_policy->m_save_pwd_chk->checkState() == Qt::Checked   && ConfigStore::store["prefs_bool_savepasswordhistory"] != "1")
    {
        ConfigStore::store["prefs_bool_savepasswordhistory"] = "1";
        m_data_changed = true;
    }

    if (m_tab_policy->m_max_hst_entries_spn->cleanText() != ConfigStore::store["prefs_int_numpwhistorydefault"])
    {
        ConfigStore::store["prefs_int_numpwhistorydefault"] = m_tab_policy->m_max_hst_entries_spn->cleanText();
        m_data_changed = true;
    }
}

/**
 * This method synchronizes the display settings with the ConfigStore.
 */
void PreferencesDialog::syncDisplayPrefs()
{
    if (m_tab_general->m_showpw_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_showpwdefault"] != "0")
    {
        ConfigStore::store["prefs_bool_showpwdefault"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_general->m_showpw_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_bool_showpwdefault"] != "1")
    {
        ConfigStore::store["prefs_bool_showpwdefault"] = "1";
        m_data_changed = true;
    }

    QString tmp = m_tab_general->m_defuser_edt->text(); tmp.replace ("\"", "\\\"");
    if (tmp != ConfigStore::store["prefs_str_defaultusername"] && m_tab_general->m_usedef_user_chk->checkState() == Qt::Checked)
    {
        ConfigStore::store["prefs_str_defaultusername"] = tmp;
        m_data_changed = true;
    }

    if (m_tab_general->m_usedef_user_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_bool_usedefuser"] != "0")
    {
        ConfigStore::store["prefs_bool_usedefuser"] = "0";
        m_data_changed = true;
    }
    else if(m_tab_general->m_usedef_user_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_bool_usedefuser"] != "1")
    {
        ConfigStore::store["prefs_bool_usedefuser"]     = "1";
        m_data_changed = true;
    }

    if (m_tab_general->m_date_format_edt->text() != ConfigStore::store["prefs_pws_date_format"])
    {
        ConfigStore::store["prefs_pws_date_format"] = (m_tab_general->m_date_format_edt->text());
        m_data_changed = true;
    }

    if (m_tab_general->m_show_grid_chk->checkState() == Qt::Unchecked && ConfigStore::store["prefs_pws_show_grid"] != "0")
    {
        ConfigStore::store["prefs_pws_show_grid"] = "0";
        m_prefs_changed = true;
    }
    else if(m_tab_general->m_show_grid_chk->checkState() == Qt::Checked && ConfigStore::store["prefs_pws_show_grid"] != "1")
    {
        ConfigStore::store["prefs_pws_show_grid"] = "1";
        m_prefs_changed = true;
    }

    if(m_tab_general->m_show_only_recent_names->checkState() == Qt::Checked && ConfigStore::store["prefs_pws_showownlyrecentname"] != "1")
    {
        ConfigStore::store["prefs_pws_showownlyrecentname"] = "1";
        m_prefs_changed = true;
    }
    else if(m_tab_general->m_show_only_recent_names->checkState() == Qt::Unchecked && ConfigStore::store["prefs_pws_showownlyrecentname"] != "0")
    {
        ConfigStore::store["prefs_pws_showownlyrecentname"] = "0";
        m_prefs_changed = true;
    }
}

/**
 * This method synchronizes the miscellaneous settings with the ConfigStore.
 */
void PreferencesDialog::syncMiscPrefs()
{
    if (m_tab_misc->m_save_backups_chk->checkState() == Qt::Checked)
    {
        ConfigStore::store["prefs_pws_save_backups"] = "1";

        if (m_tab_misc->m_numbackups_chk->checkState() == Qt::Checked)
        {
            ConfigStore::store["prefs_pws_save_num_backups"] = m_tab_misc->m_numbackups_spn->cleanText();
        }
        else 
        {
            ConfigStore::store["prefs_pws_save_num_backups"] = "";
        }

        if (m_tab_misc->m_save_backups_other_dir_chk->checkState() == Qt::Checked && m_tab_misc->m_save_backups_other_dir_edt->text() != "")
        {
            ConfigStore::store["prefs_pws_save_backups_dir"] = m_tab_misc->m_save_backups_other_dir_edt->text();
        }
        else 
        {
            ConfigStore::store["prefs_pws_save_backups_dir"] = "";
        }

        m_prefs_changed = true;
    }
    else
    {
        ConfigStore::store["prefs_pws_save_backups"] = "0";
    }

    if (m_tab_misc->m_double_cmb->currentIndex() != ConfigStore::store["prefs_pws_doubleclick_action"].toInt())
    {
        ConfigStore::store["prefs_pws_doubleclick_action"] = QString::number (m_tab_misc->m_double_cmb->currentIndex());
        m_prefs_changed = true;
    }

    if (m_tab_misc->m_enter_cmb->currentIndex() != ConfigStore::store["prefs_pws_enter_action"].toInt())
    {
        ConfigStore::store["prefs_pws_enter_action"] = QString::number (m_tab_misc->m_enter_cmb->currentIndex());
        m_prefs_changed = true;
    }

    if (m_tab_misc->m_space_cmb->currentIndex() != ConfigStore::store["prefs_pws_space_action"].toInt())
    {
        ConfigStore::store["prefs_pws_space_action"] = QString::number (m_tab_misc->m_space_cmb->currentIndex());
        m_prefs_changed = true;
    }

    if (m_tab_misc->m_scroll_cmb->currentIndex() != ConfigStore::store["prefs_pws_scroll_hint"].toInt())
    {
        ConfigStore::store["prefs_pws_scroll_hint"] = QString::number (m_tab_misc->m_scroll_cmb->currentIndex());
        m_prefs_changed = true;
    }
}

/**
 * This slot is called when the user selects the "ok" button.
 */
void PreferencesDialog::slot_okClicked()
{
    syncPwdPolicy();
    syncPwdHistory();
    syncGeneralPrefs();
    syncDisplayPrefs();
    syncMiscPrefs();

    if (m_data_changed)  emit dataChanged();
    if (m_prefs_changed) emit prefsChanged();

    close();
}

/**
 * This slot is called when the user selects the "cancel" button.
 */
void PreferencesDialog::slot_cancelClicked()
{
    close();
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
