/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PREFERENCESDIALOG_H
#define PREFERENCESDIALOG_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QDialog>
#include <QTabWidget>
#include <QMessageBox>
#include "preferenceswidgettabgeneral.h"
#include "preferenceswidgettabpolicy.h"
#include "preferenceswidgettabmisc.h"

class PreferencesDialog : public QDialog
{
    Q_OBJECT 

    public:
        /**
         * This dialog implements the preferences window.
         */
        PreferencesDialog(QWidget *parent = 0);

    signals:
        /**
         * This signal is emitted when any preference changes, that is
         * saved inside the passwordsafe.
         */
        void dataChanged();

        /**
         * This signal is emitted when any application specific
         * preference changes.
         */
        void prefsChanged();

    protected slots:

        /**
         * This slot is called when the user selects the "ok" button.
         */
        void slot_okClicked();

        /**
         * This slot is called when the user selects the "cancel" button.
         */
        void slot_cancelClicked();

    protected:
        /**
         * This method synchronizes the general preferences with the ConfigStore.
         */
        void syncGeneralPrefs();

        /**
         * This method synchronizes the password policy preferences with the ConfigStore.
         */
        void syncPwdPolicy();

        /**
         * This method synchronizes the password history settings with the ConfigStore.
         */
        void syncPwdHistory();

        /**
         * This method synchronizes the display settings with the ConfigStore.
         */
        void syncDisplayPrefs();

        /**
         * This method synchronizes the miscellaneous settings with the ConfigStore.
         */
        void syncMiscPrefs();

        bool m_data_changed;
        bool m_prefs_changed;

        /**
         * The child widgets.
         */
        PreferencesWidgetTabGeneral *m_tab_general;
        PreferencesWidgetTabPolicy  *m_tab_policy;
        PreferencesWidgetTabMisc    *m_tab_misc;

        QGridLayout *m_grid;
        QTabWidget  *m_tab;

        QPushButton *m_ok_btn;
        QPushButton *m_cancel_btn;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
