/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "preferenceswidgettabgeneral.h"

/**
 * This widget implements the general preferences tab.
 */
PreferencesWidgetTabGeneral::PreferencesWidgetTabGeneral(QWidget *parent) : QWidget(parent)
{
    createGeneralGroup();
    createDisplayGroup();

    m_vbox = new QVBoxLayout();
    m_vbox->addWidget (m_general_box);
    m_vbox->addWidget (m_display_box);

    setLayout (m_vbox);

    connect (m_usedef_user_chk, SIGNAL(stateChanged(int)), this, SLOT(slot_useDefUserClicked()));
}

/**
 * This method constructs the "general" group box.
 */
void PreferencesWidgetTabGeneral::createGeneralGroup()
{
    // create child widgets
    m_idle_timeout_chk     = new QCheckBox (tr("Lock database after n minutes"));
    m_timestamps_chk       = new QCheckBox (tr("Record last access time"));
    m_save_immediately_chk = new QCheckBox (tr("Save database immediately after any change"));
    m_confirm_del_chk      = new QCheckBox (tr("Confirm deletion of entries"));
    m_confirm_clpbrd_chk   = new QCheckBox (tr("Confirm copy to clipboard"));

    // set values according to the current ConfigStore settings
    if (ConfigStore::store["prefs_bool_maintaindatetimestamps"] == "1")
    {
        m_timestamps_chk->setCheckState (Qt::Checked);
    }

    if (ConfigStore::store["prefs_bool_saveimmediately"] == "1")
    {
        m_save_immediately_chk->setCheckState (Qt::Checked);
    }

    if (ConfigStore::store["prefs_pws_confirm_delete"] == "1")
    {
        m_confirm_del_chk->setCheckState (Qt::Checked);
    }

    if (ConfigStore::store["prefs_pws_confirm_clpbrd"] == "1")
    {
        m_confirm_clpbrd_chk->setCheckState (Qt::Checked);
    }

    if (ConfigStore::store["prefs_pws_enable_idle_timeout"] == "1")
    {
        m_idle_timeout_chk->setCheckState (Qt::Checked);
    }

    m_idle_timeout_spn = new QSpinBox();
    m_idle_timeout_spn->setRange (1, 9999);
    m_idle_timeout_spn->setValue (ConfigStore::store["prefs_int_idletimeout"].toInt());

    if (ConfigStore::store["prefs_pws_enable_idle_timeout"] == "0")
    {
        m_idle_timeout_spn->setEnabled (false);
    }

    m_clpbrd_timeout_spn  = new QSpinBox();
    m_clpbrd_timeout_spn->setRange (0, 9999);
    m_clpbrd_timeout_spn->setValue (ConfigStore::store["prefs_pws_clpbrd_timeout"].toInt());

    m_maxrecent_files_spn = new QSpinBox();
    m_maxrecent_files_spn->setRange (1, 99);
    m_maxrecent_files_spn->setValue (ConfigStore::store["prefs_pws_maxrecentfiles"].toInt());

    m_clpbrd_timeout_lbl  = new QLabel (tr("Timeout before the clipboard will be cleared"));
    m_maxrecent_files_lbl = new QLabel (tr("Maximum number of recent files"));

    // setup the layout
    m_general_grid = new QGridLayout();
    m_general_grid->addWidget (m_clpbrd_timeout_lbl,   0,0);
    m_general_grid->addWidget (m_clpbrd_timeout_spn,   0,1);
    m_general_grid->addWidget (m_maxrecent_files_lbl,  1,0);
    m_general_grid->addWidget (m_maxrecent_files_spn,  1,1);
    m_general_grid->addWidget (m_idle_timeout_chk,     2,0);
    m_general_grid->addWidget (m_idle_timeout_spn,     2,1);
    m_general_grid->addWidget (m_timestamps_chk,       3,0, 1, 2);
    m_general_grid->addWidget (m_save_immediately_chk, 4,0, 1, 2);
    m_general_grid->addWidget (m_confirm_del_chk,      5,0, 1, 2);
    m_general_grid->addWidget (m_confirm_clpbrd_chk,   6,0, 1, 2);

    m_general_box = new QGroupBox (tr("General settings"));
    m_general_box->setLayout (m_general_grid);

    connect (m_idle_timeout_chk, SIGNAL(stateChanged(int)), this, SLOT(slot_useIdleClicked()));
}

/**
 * This slot is called when the user selects the "default user" checkbox and
 * enables, resp. disables the default user field.
 */
void PreferencesWidgetTabGeneral::slot_useDefUserClicked()
{
    if (m_usedef_user_chk->checkState() == Qt::Checked)
        { m_defuser_edt->setEnabled (true); }
    else
        { m_defuser_edt->setEnabled (false); }
}

/**
 * This slot is called when the user selects the "idle timeout" checkbox and
 * enables, resp. disables the "idle timeout" spin box.
 */
void PreferencesWidgetTabGeneral::slot_useIdleClicked()
{
    if (m_idle_timeout_chk->checkState() == Qt::Checked)
        { m_idle_timeout_spn->setEnabled (true); }
    else
        { m_idle_timeout_spn->setEnabled (false); }
}

/**
 * This method constructs the "display" group box.
 */
void PreferencesWidgetTabGeneral::createDisplayGroup()
{
    // create the child widgets
    m_showpw_chk      = new QCheckBox (tr("Show passwords by default"));
    m_usedef_user_chk = new QCheckBox (tr("Use default user"));
    m_date_format_lbl = new QLabel (tr("Date format:"));

    m_defuser_edt = new QLineEdit();
    m_defuser_edt->setEnabled (false);

    m_date_format_edt = new QLineEdit();
    m_date_format_edt->setText (ConfigStore::store["prefs_pws_date_format"]);

    m_show_grid_chk        = new QCheckBox (tr("Show grid lines in display tree"));
    m_show_only_recent_names = new QCheckBox (tr("Show only filenames in recent files menu"));

    if (ConfigStore::store["prefs_pws_show_grid"] == "1")
    {
        m_show_grid_chk->setCheckState (Qt::Checked);
    }

    if (ConfigStore::store["prefs_pws_showownlyrecentname"] == "1")
    {
        m_show_only_recent_names->setCheckState (Qt::Checked);
    }

    // setup the layout
    m_display_grid = new QGridLayout();
    m_display_grid->addWidget (m_show_grid_chk,          0,0, 1, 2);
    m_display_grid->addWidget (m_show_only_recent_names, 1,0, 1, 2);
    m_display_grid->addWidget (m_showpw_chk,      2,0, 1,2);
    m_display_grid->addWidget (m_usedef_user_chk, 3,0);
    m_display_grid->addWidget (m_defuser_edt,     3,1);
    m_display_grid->addWidget (m_date_format_lbl, 4,0);
    m_display_grid->addWidget (m_date_format_edt, 4,1);

    m_display_box = new QGroupBox (tr("Display settings"));
    m_display_box->setLayout (m_display_grid);

    // set all values accordingly to the values in ConfigStore
    if (ConfigStore::store["prefs_bool_showpwdefault"] == "1")
        { m_showpw_chk->setCheckState(Qt::Checked); }

    if (ConfigStore::store["prefs_bool_usedefuser"] == "1")
    {
        m_usedef_user_chk->setCheckState(Qt::Checked);
        m_defuser_edt->setEnabled (true);

        QString tmp = ConfigStore::store["prefs_str_defaultusername"];
        m_defuser_edt->setText (tmp.replace ("\\", ""));
    }
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
