/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PREFERENCESWIDGETTABGENERAL_H
#define PREFERENCESWIDGETTABGENERAL_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QCheckBox>
#include <QSpinBox>
#include <QGroupBox>
#include <QComboBox>
#include "configstore.h"

class PreferencesWidgetTabGeneral : public QWidget
{
    Q_OBJECT 

    public:
        /**
         * This widget implements the general preferences tab.
         */
        PreferencesWidgetTabGeneral(QWidget *parent = 0);

        /**
         * The child widgets. These widgets are public and its values will
         * be read by PreferencesDialog.
         */
        QCheckBox *m_pwd_length_lbl;
        QCheckBox *m_timestamps_chk;
        QCheckBox *m_save_immediately_chk;
        QCheckBox *m_confirm_del_chk;
        QCheckBox *m_confirm_clpbrd_chk;
        QCheckBox *m_show_grid_chk;
        QCheckBox *m_showpw_chk;
        QCheckBox *m_usedef_user_chk;
        QCheckBox *m_idle_timeout_chk;
        QCheckBox *m_show_only_recent_names;

        QLineEdit *m_defuser_edt;
        QLineEdit *m_date_format_edt;

        QSpinBox *m_idle_timeout_spn;
        QSpinBox *m_clpbrd_timeout_spn;
        QSpinBox *m_maxrecent_files_spn;

    protected slots:

        /**
         * This slot is called when the user selects the "default user" checkbox and
         * enables, resp. disables the default user field.
         */
        void slot_useDefUserClicked();


        /**
         * This slot is called when the user selects the "idle timeout" checkbox and
         * enables, resp. disables the "idle timeout" spin box.
         */
        void slot_useIdleClicked();

    protected:
        /**
         * This method constructs the "general" group box.
         */
        void createGeneralGroup();

        /**
         * This method constructs the "display" group box.
         */
        void createDisplayGroup();

        /**
         * Create all non-public child widgets.
         */
        QLabel *m_clpbrd_timeout_lbl;
        QLabel *m_maxrecent_files_lbl;
        QLabel *m_date_format_lbl;

        QGroupBox *m_general_box;
        QGroupBox *m_display_box;

        QGridLayout *m_display_grid;
        QGridLayout *m_general_grid;

        QVBoxLayout *m_vbox;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
