/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "preferenceswidgettabmisc.h"

/**
 * This widget represents the backup settings tab.
 */
PreferencesWidgetTabMisc::PreferencesWidgetTabMisc(QWidget *parent) : QWidget(parent)
{
    createBackupGroup();
    createActionsGroup();

    m_vbox = new QVBoxLayout();
    m_vbox->addWidget (m_backup_box);
    m_vbox->addWidget (m_actions_box);

    m_vbox->setStretchFactor (m_actions_box, 255);

    setLayout (m_vbox);

    connect (m_save_backups_chk, SIGNAL(stateChanged(int)),           this, SLOT(slot_saveBackups()));
    connect (m_numbackups_chk,   SIGNAL(stateChanged(int)),           this, SLOT(slot_numBackups()));
    connect (m_dots_btn,         SIGNAL(clicked()),                   this, SLOT(slot_dotsClicked()));
    connect (m_save_backups_other_dir_chk, SIGNAL(stateChanged(int)), this, SLOT(slot_otherDir()));
    connect (m_save_backups_same_dir_chk,  SIGNAL(stateChanged(int)), this, SLOT(slot_sameDir()));
}

/**
 * Creates the backup setting group box.
 */
void PreferencesWidgetTabMisc::createBackupGroup()
{
    // create the child widgets
    m_save_backups_dir_lbl = new QLabel (tr("Save backups in ..."));

    m_save_backups_chk           = new QCheckBox (tr("Save backups"));
    m_numbackups_chk             = new QCheckBox (tr("Maximum number of backups"));
    m_save_backups_same_dir_chk  = new QCheckBox (tr("... same directory as database"));
    m_save_backups_other_dir_chk = new QCheckBox (tr("... other directory"));

    m_dots_btn = new QPushButton(tr("..."));
    m_dots_btn->setMinimumWidth    (40);
    m_dots_btn->setMaximumWidth    (40);

    m_save_backups_other_dir_edt = new QLineEdit();

    m_numbackups_spn = new QSpinBox();
    m_numbackups_spn->setRange (1, 255);

    // setup the layout
    m_backup_grid = new QGridLayout();
    m_backup_grid->addWidget (m_save_backups_chk,            0,0);
    m_backup_grid->addWidget (m_numbackups_chk,              1,0);
    m_backup_grid->addWidget (m_numbackups_spn,              1,1);
    m_backup_grid->addWidget (m_save_backups_dir_lbl,        2,0);
    m_backup_grid->addWidget (m_save_backups_same_dir_chk,        3,0);
    m_backup_grid->addWidget (m_save_backups_other_dir_chk,  4,0);
    m_backup_grid->addWidget (m_save_backups_other_dir_edt,  5,0, 1,2);
    m_backup_grid->addWidget (m_dots_btn,                    5,2);

    m_backup_grid->setColumnStretch (0, 0);
    m_backup_grid->setColumnStretch (1, 255);
    m_backup_grid->setColumnStretch (2, 0);

    m_backup_grid->setRowStretch (0, 0);
    m_backup_grid->setRowStretch (1, 0);
    m_backup_grid->setRowStretch (2, 0);
    m_backup_grid->setRowStretch (3, 0);
    m_backup_grid->setRowStretch (4, 0);
    m_backup_grid->setRowStretch (6, 255);

    m_backup_box = new QGroupBox (tr("Backup settings"));
    m_backup_box->setLayout (m_backup_grid);

    // set all values according to the settings in ConfigStore
    if (ConfigStore::store["prefs_pws_save_backups"] == "1")
    {
        m_save_backups_chk->setCheckState (Qt::Checked);
    }
    else
    {
        m_numbackups_chk->setEnabled (false);
        m_save_backups_same_dir_chk->setEnabled (false);
        m_save_backups_other_dir_chk->setEnabled (false);
        m_numbackups_spn->setEnabled(false);
        m_save_backups_other_dir_edt->setEnabled (false);
    }

    if (ConfigStore::store["prefs_pws_save_num_backups"] != "")
    {
        m_numbackups_chk->setCheckState (Qt::Checked);
        m_numbackups_spn->setValue(ConfigStore::store["prefs_pws_save_num_backups"].toInt());
    }
    else
    {
        m_numbackups_chk->setCheckState (Qt::Unchecked);
        m_numbackups_spn->setValue(0);
        m_numbackups_spn->setEnabled(false);
    }

    if (ConfigStore::store["prefs_pws_save_backups_dir"] != "")
    {
        m_save_backups_other_dir_chk->setCheckState (Qt::Checked);
        m_save_backups_other_dir_edt->setText (ConfigStore::store["prefs_pws_save_backups_dir"]);
    }
    else
    {
        m_save_backups_same_dir_chk->setCheckState (Qt::Checked);
        m_save_backups_other_dir_chk->setCheckState (Qt::Unchecked);
        m_save_backups_other_dir_edt->setEnabled (false);
    }
}

/**
 * This slot is called when the user selects the "max number of backups"
 * checkbox and enables/disables the corresponding spinbox.
 */
void PreferencesWidgetTabMisc::slot_numBackups()
{
    if (m_numbackups_chk->checkState() == Qt::Checked)
    {
        m_numbackups_spn->setEnabled(true);
    }
    else
    {
        m_numbackups_spn->setEnabled(false);
    }
}

/**
 * This slot is called when the user selects the "save backups in same dir as database"
 * checkbox and enables/disables the "save backups in other dir" checkbox.
 */
void PreferencesWidgetTabMisc::slot_sameDir()
{
    if (m_save_backups_same_dir_chk->checkState() == Qt::Checked)
    {
        m_save_backups_other_dir_chk->setCheckState (Qt::Unchecked);
    }
}

/**
 * This slot is called when the user selects the "save backups in other dir"
 * checkbox and enables/disables the corresponding text edit field and the
 * "save backups in same dir" checkbox.
 */
void PreferencesWidgetTabMisc::slot_otherDir()
{
    if (m_save_backups_other_dir_chk->checkState() == Qt::Checked)
    {
        m_save_backups_other_dir_edt->setEnabled(true);
        m_save_backups_same_dir_chk->setCheckState (Qt::Unchecked);
    }
    else
    {
        m_save_backups_other_dir_edt->setEnabled(false);
    }
}

/**
 * This slot is called when the user selects the "save backups"
 * checkbox and enables/disables all (functional) subwidgets of this widget.
 */
void PreferencesWidgetTabMisc::slot_saveBackups()
{
    if (m_save_backups_chk->checkState() == Qt::Checked)
    {
        m_numbackups_chk->setEnabled (true);
        m_save_backups_same_dir_chk->setEnabled (true);
        m_save_backups_other_dir_chk->setEnabled (true);
        m_numbackups_spn->setEnabled(true);
        m_save_backups_other_dir_edt->setEnabled (true);
    }
    else
    {
        m_numbackups_chk->setEnabled (false);
        m_save_backups_same_dir_chk->setEnabled (false);
        m_save_backups_other_dir_chk->setEnabled (false);
        m_numbackups_spn->setEnabled(false);
        m_save_backups_other_dir_edt->setEnabled (false);
    }
}

/**
 * This slot is called when the user selects the "dots" button and opens
 * a file dialog.
 */
void PreferencesWidgetTabMisc::slot_dotsClicked()
{
    QString filename = QFileDialog::getExistingDirectory(this, tr("Choose backup directory"), "");

    if (filename != "" || m_save_backups_other_dir_edt->text() != "")
    {
        if (filename != "")
        {
            m_save_backups_other_dir_edt->setText (filename);
        }

        m_save_backups_other_dir_edt->setEnabled (true);
        m_save_backups_same_dir_chk->setCheckState (Qt::Unchecked);
        m_save_backups_other_dir_chk->setCheckState (Qt::Checked);
    }
    else
    {
        m_save_backups_other_dir_chk->setCheckState (Qt::Unchecked);
        m_save_backups_same_dir_chk->setCheckState (Qt::Checked);
    }
}

/**
 * This method constructs the "actions" group box.
 */
void PreferencesWidgetTabMisc::createActionsGroup()
{
    // create the child widgets
    m_double_lbl = new QLabel(tr("Double click action: "));

    m_double_cmb = new QComboBox();
    m_double_cmb->setEditable (false);
    m_double_cmb->addItem(tr("Edit password entry"));
    m_double_cmb->addItem(tr("Copy password to clipboard"));
    m_double_cmb->addItem(tr("Copy username to clipboard"));
    m_double_cmb->addItem(tr("Copy url to clipboard"));
    m_double_cmb->addItem(tr("Open url"));

    m_enter_lbl = new QLabel(tr("Enter key action: "));

    m_enter_cmb = new QComboBox();
    m_enter_cmb->setEditable (false);
    m_enter_cmb->addItem(tr("Edit password entry"));
    m_enter_cmb->addItem(tr("Copy password to clipboard"));
    m_enter_cmb->addItem(tr("Copy username to clipboard"));
    m_enter_cmb->addItem(tr("Copy url to clipboard"));
    m_enter_cmb->addItem(tr("Open url"));

    m_space_lbl = new QLabel(tr("Space key action: "));

    m_space_cmb = new QComboBox();
    m_space_cmb->setEditable (false);
    m_space_cmb->addItem(tr("Edit password entry"));
    m_space_cmb->addItem(tr("Copy password to clipboard"));
    m_space_cmb->addItem(tr("Copy username to clipboard"));
    m_space_cmb->addItem(tr("Copy url to clipboard"));
    m_space_cmb->addItem(tr("Open url"));

    m_scroll_lbl = new QLabel(tr("When expanding: "));

    m_scroll_cmb = new QComboBox();
    m_scroll_cmb->setEditable (false);
    m_scroll_cmb->addItem(tr("Ensure item is visible"));
    m_scroll_cmb->addItem(tr("Position selected item at top"));

    // set all values accordingly to the values in ConfigStore
    m_double_cmb->setCurrentIndex (ConfigStore::store["prefs_pws_doubleclick_action"].toInt());
    m_enter_cmb->setCurrentIndex  (ConfigStore::store["prefs_pws_enter_action"].toInt());
    m_space_cmb->setCurrentIndex  (ConfigStore::store["prefs_pws_space_action"].toInt());
    m_scroll_cmb->setCurrentIndex (ConfigStore::store["prefs_pws_scroll_hint"].toInt());
    
    // setup the layout
    m_actions_grid = new QGridLayout();
    m_actions_grid->addWidget (m_double_lbl, 0,0);
    m_actions_grid->addWidget (m_double_cmb, 0,1);
    m_actions_grid->addWidget (m_enter_lbl,  1,0);
    m_actions_grid->addWidget (m_enter_cmb,  1,1);
    m_actions_grid->addWidget (m_space_lbl,  2,0);
    m_actions_grid->addWidget (m_space_cmb,  2,1);
    m_actions_grid->addWidget (m_scroll_lbl,  3,0);
    m_actions_grid->addWidget (m_scroll_cmb,  3,1);

    m_actions_grid->setColumnStretch (0, 0); 
    m_actions_grid->setColumnStretch (1, 255); 
    m_actions_grid->setRowStretch    (4, 255); 

    m_actions_box = new QGroupBox (tr("Actions"));
    m_actions_box->setLayout (m_actions_grid);
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
