/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PREFERENCESWIDGETTABMISC_H
#define PREFERENCESWIDGETTABMISC_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QCheckBox>
#include <QSpinBox>
#include <QGroupBox>
#include <QComboBox>
#include <QFileDialog>
#include "configstore.h"

class PreferencesWidgetTabMisc : public QWidget
{
    Q_OBJECT 

    public:
        /**
         * This widget represents the backup settings tab.
         */
        PreferencesWidgetTabMisc(QWidget *parent = 0);

        /**
         * Public child widgets which will be read by PreferencesDialog.
         */
        QCheckBox *m_save_backups_chk;
        QCheckBox *m_numbackups_chk;
        QCheckBox *m_save_backups_same_dir_chk;
        QCheckBox *m_save_backups_other_dir_chk;

        QLineEdit *m_save_backups_other_dir_edt;
        QSpinBox *m_numbackups_spn;

        QLabel    *m_double_lbl;
        QLabel    *m_enter_lbl;
        QLabel    *m_space_lbl;
        QLabel    *m_scroll_lbl;

        QComboBox *m_double_cmb;
        QComboBox *m_enter_cmb;
        QComboBox *m_space_cmb;
        QComboBox *m_scroll_cmb;

    protected slots:
        /**
         * This slot is called when the user selects the "save backups"
         * checkbox and enables/disables all (functional) subwidgets of this widget.
         */
        void slot_saveBackups();

        /**
         * This slot is called when the user selects the "max number of backups"
         * checkbox and enables/disables the corresponding spinbox.
         */
        void slot_numBackups();

        /**
         * This slot is called when the user selects the "save backups in other dir"
         * checkbox and enables/disables the corresponding text edit field and the
         * "save backups in same dir" checkbox.
         */
        void slot_otherDir();

        /**
         * This slot is called when the user selects the "save backups in same dir as database"
         * checkbox and enables/disables the "save backups in other dir" checkbox.
         */
        void slot_sameDir();

        /**
         * This slot is called when the user selects the "dots" button and opens
         * a file dialog.
         */
        void slot_dotsClicked();

    protected:
        /**
         * Creates the backup setting group box.
         */
        void createBackupGroup();

        /**
         * This method constructs the "actions" group box.
         */
        void createActionsGroup();

        /**
         * All private child widgets.
         */
        QLabel *m_save_backups_dir_lbl;

        QPushButton *m_dots_btn;

        QGroupBox *m_backup_box;
        QGroupBox *m_actions_box;

        QGridLayout *m_backup_grid;
        QGridLayout *m_actions_grid;

        QVBoxLayout *m_vbox;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
