/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PREFERENCESWIDGETTABPOLICY_H
#define PREFERENCESWIDGETTABPOLICY_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QTextEdit>
#include <QPushButton>
#include <QCheckBox>
#include <QSpinBox>
#include <QGroupBox>
#include "configstore.h"

class PreferencesWidgetTabPolicy : public QWidget
{
    Q_OBJECT 

    public:
        /**
         * This widgets represents the password policy and history preferences tab.
         */
        PreferencesWidgetTabPolicy(QWidget *parent = 0);

        /**
         * Public child widgets which will be read by PreferencesDialog.
         */
        QCheckBox *m_lower_case_chk;
        QCheckBox *m_upper_case_chk;
        QCheckBox *m_digits_chk;
        QCheckBox *m_symbols_chk;
        QCheckBox *m_easy_chk;
        QCheckBox *m_hex_chk;
        QCheckBox *m_save_pwd_chk;

        QSpinBox *m_pwd_length_spin;
        QSpinBox *m_max_hst_entries_spn;

    protected slots:
        /**
         * This slot is called whenever the user selects the "use only hex characters"
         * checkbox and unchecks all other password policy checkboxes.
         */
        void slot_hexChkStateChanged(int state);

        /**
         * This slot is called whenever the user selects the "use only easy characters"
         * checkbox.
         */
        void slot_easyChkChanged(int state);

        /**
         * This slot is called whenever the user selects the "use lower case characters"
         * checkbox.
         */
        void slot_lowerChkChanged(int state);

        /**
         * This slot is called whenever the user selects the "use upper case characters"
         * checkbox.
         */
        void slot_upperChkChanged(int state);

        /**
         * This slot is called whenever the user selects the "use digits characters"
         * checkbox.
         */
        void slot_digitsChkChanged(int state);

        /**
         * This slot is called whenever the user selects the "use symbols characters"
         * checkbox.
         */
        void slot_symbolsChkChanged(int state);

    protected:
        /**
         * Creates the password policy group box.
         */
        void createPwdPolicyGroup();

        /**
         * Creates the password history group box.
         */
        void createPwdHistoryGroup();

        /**
         * Create all non-public child widgets.
         */
        QLabel    *m_pwd_length_lbl;

        QGroupBox *m_pwd_policy_box;
        QGroupBox *m_pwd_history_box;

        QGridLayout *m_pwd_policy_grid;
        QGridLayout *m_pwd_history_grid;
        QVBoxLayout *m_vbox;
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
