#include "pwstreeview.h"

PWSTreeView::PWSTreeView (QWidget * parent) : QTreeView (parent) { } 

/**
 * Handle all mouse press events.
 */
void PWSTreeView::mousePressEvent(QMouseEvent *event)
{
    QTreeView::mousePressEvent(event);

    if (event->button() == Qt::LeftButton)
    {
        dragStartPosition = event->pos(); 
    }
}

/**
 * Handle all mouse move events.
 */
void PWSTreeView::mouseMoveEvent(QMouseEvent *event)
{
    if (ConfigStore::store["readonly"] == "1")
        { return; }

    if (!(event->buttons() & Qt::LeftButton))
        { return; }

    if ((event->pos() - dragStartPosition).manhattanLength() < QApplication::startDragDistance())
        { return; }

    if (indexAt (dragStartPosition).isValid())
    {
        QDrag *drag = new QDrag(this);
        EntryItem *item = static_cast<EntryItem*>(indexAt(dragStartPosition).internalPointer());

        if (item->isGroup())
            { drag->setPixmap(QIcon(":/images/folder.png").pixmap(15,15)); }
        else
            { drag->setPixmap(QIcon(":/images/entry.png").pixmap(15,15)); }

        drag->setMimeData(item->toMimeData());
        drag->exec(Qt::CopyAction | Qt::MoveAction);
    }
}

/**
 * Handle all drag enter events.
 */
void PWSTreeView::dragEnterEvent(QDragEnterEvent *event)
{
    if (ConfigStore::store["readonly"] == "1")
        { event->ignore(); return; }

    if (event->mimeData()->hasFormat("application/pws.dragdrop.entry"))
        { event->acceptProposedAction(); }
}

/**
 * Import dropped data if applicable.
 */
void PWSTreeView::dropEvent(QDropEvent *event)
{
    if (ConfigStore::store["readonly"] == "1")
        { event->ignore(); return; }

    QPersistentModelIndex src_index (indexAt(dragStartPosition));

    QPersistentModelIndex index (indexAt(event->pos()));
    if (event->source() && index == indexAt(dragStartPosition))
        { event->ignore(); return; }

    EntryItem * parent = ((PWSTreeModel*)model())->root();
    if (index.isValid())
        { parent = static_cast<EntryItem*>(index.internalPointer()); }

    event->acceptProposedAction();

    if (parent != ((PWSTreeModel*)model())->root())
        { setExpanded (index, true); }

    if (parent->isGroup())
    {
        QList<EntryItem*> entries = EntryItem::fromMimeData (event->mimeData());
        QListIterator<EntryItem*> iter(entries);
        while (iter.hasNext())
            { ((PWSTreeModel*)model())->addEntry (iter.next(), index); }
    }
    else
    {
        QList<EntryItem*> entries = EntryItem::fromMimeData (event->mimeData());
        QListIterator<EntryItem*> iter(entries);
        while (iter.hasNext())
            { ((PWSTreeModel*)model())->addEntry (iter.next(), index.parent()); }
    }

    ((PWSTreeModel*)model())->sort(NULL);

    if (event->source())
        { model()->removeRow (src_index.row(), src_index.parent()); }

    emit dropSuccessfull();
}

/**
 * Handle all drag move events.
 */
void PWSTreeView::dragMoveEvent (QDragMoveEvent * event) 
{
    if (ConfigStore::store["readonly"] == "1")
        { event->ignore(); return; }

    if (event->source())
    {
        EntryItem * item    = static_cast<EntryItem*>(indexAt(dragStartPosition).internalPointer());
        EntryItem * curItem = static_cast<EntryItem*>(indexAt(event->pos()).internalPointer());

        if (curItem == item || curItem == item->getParent())
            { event->ignore(); return; }

        if (!indexAt(event->pos()).isValid() && item->getParent() == ((PWSTreeModel*)model())->root())
            { event->ignore(); return; }

        if (indexAt(event->pos()).isValid() && !curItem->isGroup()   && 
            curItem->getParent() == ((PWSTreeModel*)model())->root() &&
            item->getParent() == ((PWSTreeModel*)model())->root())
            { event->ignore(); return; }

        if (indexAt(event->pos()).isValid() && !curItem->isGroup()   &&
            curItem->getParent() == item->getParent())
            { event->ignore(); return; }

        while (curItem && curItem->getParent())
        {
            if (curItem->getParent() == item)
                { event->ignore(); return; }
            curItem = curItem->getParent();
        }
    }

    if (event->mimeData()->hasFormat("application/pws.dragdrop.entry"))
        { event->acceptProposedAction(); }
    else
        { event->ignore(); }
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
