/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PWSTREEVIEW_H
#define PWSTREEVIEW_H

#include <QtGui>
#include <QPersistentModelIndex>
#include <iostream>
#include <sys/types.h>
#include <unistd.h>
#include "entryitem.h"
#include "pwstreemodel.h"
#include "configstore.h"

/**
 * Extend QTreeView with drag and drop functionality.
 */
class PWSTreeView : public QTreeView
{
    Q_OBJECT

    public:
        PWSTreeView (QWidget * parent = 0);

    signals:
        /**
         * This signal will be emitted whenever a drop action was
         * successfull.
         */
        void dropSuccessfull();

    protected:

        /**
         * This is the position, where the drag and drop operation
         * started.
         */
        QPoint dragStartPosition;

        /**
         * Handle all mouse press events.
         */
        void mousePressEvent(QMouseEvent *event);

        /**
         * Handle all mouse move events.
         */
        void mouseMoveEvent(QMouseEvent *event);

        /**
         * Handle all drag enter events.
         */
        void dragEnterEvent(QDragEnterEvent *event);

        /**
         * Import dropped data if applicable.
         */
        void dropEvent(QDropEvent *event);

        /**
         * Handle all drag move events.
         */
        void dragMoveEvent (QDragMoveEvent * event);
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
