/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef STARTDIALOG_H
#define STARTDIALOG_H

#include <QWidget>
#include <QGridLayout>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include <QDialog>
#include <QMessageBox>
#include <QCheckBox>
#include <QComboBox>
#include <QFileDialog>
#include "startdialog.h"
#include "configstore.h"
#include "newpassphrasedialog.h"
#include "pwshandler.h"

class StartDialog : public QDialog
{
    Q_OBJECT 

    public:
        /**
         * This dialog is shown when pws is started.
         */
        StartDialog(QWidget *parent = 0);

    signals:
        /**
         * This signal is emitted when the user selects the "ok" button.
         *
         * @param passphrase - The passphrase.
         * @param readonly - True if the readonly checkbox was checked, otherwise false.
         */
        void okClicked(const QString & passphrase, bool readonly);

        /**
         * This signal is emitted when the user selects the "cancel" button.
         */
        void cancelClicked();

        /**
         * This signal is emitted when the user selects the "new" button.
         *
         * @param passphrase - The passphrase.
         */
        void newClicked(const QString &);

    protected:
        /**
         * The child widgets.
         */
        QLineEdit   *m_pwd_edt;
        QLineEdit   *m_recent_edt;

        QPushButton *m_ok_btn;
        QPushButton *m_new_btn;
        QPushButton *m_dots_btn;
        QPushButton *m_cancel_btn;

        QCheckBox   *m_readonly_chk;
        QComboBox   *m_recent_cmb;

        QLabel      *m_recent_lbl;
        QLabel      *m_pwd_lbl;

        QGridLayout *m_grid;

    protected slots:
        /**
         * This slot is called when the user selects the dots button.
         */
        void slot_dotsClicked();

        /**
         * This slot is called when the user selects the "ok" button.
         */
        void slot_okClicked();

        /**
         * This slot is called when the user selects the "new" button.
         */
        void slot_newClicked();

        /**
         * Set the focus to the passphrase field.
         */
        void slot_setEditFocus();

        /**
         * This slot is called when the user entered a wrong passphrase.
         */
        void slot_wrongPassphrase();
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
