/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#include "unlockdialog.h"

/**
 * This class is shown at the time the idle timer in MainWindow
 * times out.
 */
UnlockDialog::UnlockDialog(PWSHandler * handler, QWidget *parent) : QDialog(parent)
{   
    setAttribute (Qt::WA_DeleteOnClose, true);

    pwsHandler = handler;

    m_locked = true;

    m_pwd_lbl    = new QLabel(tr("Enter passphrase:"));
    m_pwd_edt    = new QLineEdit();
    m_ok_btn     = new QPushButton (tr("&Ok"));

    m_pwd_edt->setEchoMode (QLineEdit::Password);
    m_pwd_edt->setMinimumWidth (240);

    m_ok_btn->setMinimumWidth  (120);
    m_ok_btn->setMaximumWidth  (120);

    m_grid = new QGridLayout();
    m_grid->addWidget (m_pwd_lbl, 0,0 ,1,2);
    m_grid->addWidget (m_pwd_edt, 1,0 ,1,2);
    m_grid->addWidget (m_ok_btn,  2,1);

    setLayout (m_grid);
    setWindowTitle (tr("Enter passphrase"));

    connect (m_ok_btn, SIGNAL(clicked(bool)), this, SLOT(slot_okClicked()));

    // submit on enter
    (void) new QShortcut(Qt::Key_Enter,  this, SLOT(slot_okClicked()));
    (void) new QShortcut(Qt::Key_Return, this, SLOT(slot_okClicked()));
}

/**
 * Give the main windows a chance to save the database before closing
 * the app - emit a toBeClosed() signal.
 */
void UnlockDialog::closeEvent(QCloseEvent * event)
{
    if (m_locked) emit toBeClosed();

    event->accept();
}

/**
 * This slot is called when the user selects the ok button.
 */
void UnlockDialog::slot_okClicked ()
{
    // verify passphrase and unlock pws
    if (pwsHandler->verifyPassphrase (m_pwd_edt->text()))
    {
        m_locked = false;
        emit submit();

        close();
    }
    else
    {
        m_pwd_edt->selectAll();
        QMessageBox::critical(this, tr("Error"), tr("Wrong passphrase.")); return;
    }
}

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
