/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007-2008 by Timo Benk                                  *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef UNLOCKDIALOG_H
#define UNLOCKDIALOG_H

#include <QWidget>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include <QGridLayout>
#include <QMessageBox>
#include <QCheckBox>
#include <QDialog>
#include <QShortcut>
#include <QCloseEvent>
#include <iostream>
#include "configstore.h"
#include "pwshandler.h"

class UnlockDialog : public QDialog
{
    Q_OBJECT 

    public:
        /**
         * This class is shown at the time the idle timer in MainWindow
         * times out.
         */
        UnlockDialog(PWSHandler * handler, QWidget *parent = 0);

    signals:
        /**
         * This signal is emitted when the user enters the correct
         * passphrase.
         */
        void submit ();

        /**
         * Will be emitted just before this dialog will be closed.
         */
        void toBeClosed();

    protected:
        /**
         * Child widgets.
         */
        QGridLayout *m_grid;
        QLineEdit   *m_pwd_edt;;
        QLabel      *m_pwd_lbl;
        QPushButton *m_ok_btn;

        /**
         * The PWSHandler object.
         */
        PWSHandler * pwsHandler;

        /**
         * Will be set to true while locked.
         */
        bool m_locked;

        /**
         * Give the main windows a chance to save the database before closing
         * the app - emit a toBeClosed() signal.
         */
        void closeEvent(QCloseEvent * event);

    public slots:
        /**
         * This slot is called when the user selects the ok button.
         */
        void slot_okClicked ();
};

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
